@@ -1,7 +1,7 @@
 '''
 Taken from salt: salt/utils/jinja.py
 
-Copyright (c) 2015 - 2024 Rob "N3X15" Nelson <nexisentertainment@gmail.com>
+Copyright (c) 2015 - 2025 Rob "N3X15" Nelson <nexisentertainment@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -21,12 +21,6 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
-
-MODIFICATIONS:
-
-Jan 16 2021:
- * Converted PyYAML to ruamel.yaml.
-
 '''
 
 # Import python libs
